@@ -15,7 +15,7 @@ Subprocess class features:
 
  - RecordFile class provides record-oriented IO for file-like stream objects.
 
-$Id: subproc.py 1753 2012-05-29 19:12:14Z sontag $
+$Id$
 """
 from __future__ import division # confidence high
 
@@ -863,7 +863,7 @@ class RedirProcess(Subprocess):
 def test(fout = sys.stdout):
     fout.write("Starting test ...\n")
     assert hasattr(fout, 'write'), "Input not a file object: "+str(fout)
-    print "\tOpening subprocess:"
+    print "\tOpening subprocess (4 Jan 2017):"
     p = Subprocess('cat', expire_noisily=1)        # set to expire noisily...
     print p
     print "\tOpening bogus subprocess, should fail:"
